aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/utility.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/utility.hxx')
-rw-r--r--libbuild2/utility.hxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/libbuild2/utility.hxx b/libbuild2/utility.hxx
index f37fc54..594808c 100644
--- a/libbuild2/utility.hxx
+++ b/libbuild2/utility.hxx
@@ -185,12 +185,14 @@ namespace build2
LIBBUILD2_SYMEXPORT extern const string build_version_interface;
// Whether running installed build as well as the library installation
// directory (only if installed, empty otherwise) and the exported buildfile
// installation directory (only if configured, empty otherwise).
//
LIBBUILD2_SYMEXPORT extern const bool build_installed;
LIBBUILD2_SYMEXPORT extern const dir_path build_install_lib; // $install.lib
LIBBUILD2_SYMEXPORT extern const dir_path build_install_buildfile; // $install.buildfile
+ LIBBUILD2_SYMEXPORT extern const dir_path build_install_data; // $install.data
// --[no-]mtime-check
//
@@ -185,12 +185,14 @@ namespace build2
LIBBUILD2_SYMEXPORT extern const string build_version_interface;
// Whether running installed build as well as the library installation
- // directory (only if installed, empty otherwise) and the exported buildfile
- // installation directory (only if configured, empty otherwise).
+ // directory (only if installed, empty otherwise), the exported buildfile
+ // installation directory (only if configured, empty otherwise), and data
+ // installation directory (only if installed, src_root otherwise).
//
LIBBUILD2_SYMEXPORT extern const bool build_installed;